summaryrefslogtreecommitdiff
path: root/NxWidgets/nxwm/include/cfullscreenwindow.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'NxWidgets/nxwm/include/cfullscreenwindow.hxx')
-rw-r--r--NxWidgets/nxwm/include/cfullscreenwindow.hxx30
1 files changed, 21 insertions, 9 deletions
diff --git a/NxWidgets/nxwm/include/cfullscreenwindow.hxx b/NxWidgets/nxwm/include/cfullscreenwindow.hxx
index 2e3fbd45d..1bab37543 100644
--- a/NxWidgets/nxwm/include/cfullscreenwindow.hxx
+++ b/NxWidgets/nxwm/include/cfullscreenwindow.hxx
@@ -43,6 +43,7 @@
#include <nuttx/config.h>
#include "cnxwindow.hxx"
+#include "cwidgetcontrol.hxx"
#include "iapplicationwindow.hxx"
@@ -115,12 +116,19 @@ namespace NxWM
NXWidgets::INxWindow *getWindow(void) const;
/**
* Recover the contained window control
*
* @return. The window control used by this application
*/
- CWindowControl *getWindowControl(void) const;
+ NXWidgets::CWidgetControl *getWidgetControl(void) const;
+
+ /**
+ * Block further activity on this window in preparation for window
+ * shutdown.
+ */
+
+ void block(void);
/**
* Set the window label
@@ -147,21 +155,25 @@ namespace NxWM
void registerCallbacks(IApplicationCallback *callback);
/**
- * Simulate a mouse click on the minimize icon. This inline method is only
- * used during automated testing of NxWM.
+ * Simulate a mouse click or release on the minimize icon. This method
+ * is only available for automated testing of NxWM.
+ *
+ * @param click. True to click; false to release;
*/
#if defined(CONFIG_NXWM_UNITTEST) && !defined(CONFIG_NXWM_TOUCHSCREEN)
- void clickMinimizeIcon(int index);
+ void clickMinimizePosition(bool click);
#endif
/**
- * Simulate a mouse click on the stop applicaiton icon. This inline method is only
- * used during automated testing of NxWM.
+ * Simulate a mouse click or release on the stop icon. This method
+ * is only available for automated testing of NxWM.
+ *
+ * @param click. True to click; false to release;
*/
#if defined(CONFIG_NXWM_UNITTEST) && !defined(CONFIG_NXWM_TOUCHSCREEN)
- void clickStopIcon(int index);
+ void clickStopIcon(bool click);
#endif
};
}
@@ -115,12 +116,19 @@ namespace NxWM
NXWidgets::INxWindow *getWindow(void) const;
/**
- * Recover the contained window control
+ * Recover the contained widget control
*
@@ -115,12 +116,19 @@ namespace NxWM
*
- * @return. The window control used by this application
+ * @return. The widget control used by this application
*/